OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
    "Storage invalid" : "Armazenamento inválido",
    "Unknown error" : "Erro desconhecido",
    "File could not be found" : "O arquivo não foi encontrado",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Baixar",
    "Delete" : "Excluir",
    "Home" : "Início",
    "Close" : "Fechar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "This will stop your current uploads." : "Isso irá parar seus envios atuais.",
    "Upload cancelled." : "Envio cancelado.",
    "Processing files …" : "Processando arquivos...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não foi possível fazer o envio de {filename}, pois é um diretório ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não há espaço suficiente, você está enviando {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Pasta de destino \"{dir}\" não existe mais",
    "Not enough free space" : "Espaço livre insuficiente",
    "An unknown error has occurred" : "Um erro desconhecido ocorreu",
    "File could not be uploaded" : "Não foi possível enviar o arquivo",
    "Uploading …" : "Enviando...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "O envio deste item não é suportado",
    "Target folder does not exist any more" : "Pasta destino não existe mais",
    "Operation is blocked by access control" : "A operação está bloqueada pelo controle de acesso",
    "Error when assembling chunks, status code {status}" : "Erro ao montar partes, código de status {status}",
    "Actions" : "Ações",
    "Rename" : "Renomear",
    "Move" : "Mover",
    "Copy" : "Copiar",
    "Choose target folder" : "Escolher pasta destino",
    "Open" : "Abrir",
    "Delete file" : "Excluir arquivo",
    "Delete folder" : "Excluir pasta",
    "Disconnect storage" : "Desconectar armazenamento",
    "Leave this share" : "Sair deste compartilhamento",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações para o arquivo \"{file}\" ",
    "Files" : "Arquivos",
    "Details" : "Detalhes",
    "Show list view" : "Mostrar visualização em lista",
    "Show grid view" : "Mostrar visualização em grade",
    "Please select tag(s) to add to the selection" : "Selecione a(s) etiquetas(s) para adicionar à seleção ",
    "Apply tag(s) to selection" : "Aplicar as etiqueta(s) a seleção",
    "Select directory \"{dirName}\"" : "Selecione o diretório \"{dirName}\"",
    "Select file \"{fileName}\"" : "Selecione o arquivo \"{fileName}\"",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este diretório não está disponível, por favor verifique os logs ou contacte o administrador",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\" pois o destino já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", pois já existe",
    "Could not copy \"{file}\"" : "Não foi possível copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} foi copiado para {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} e outros {nbfiles} arquivos foram copiados para {destination}",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\" pois ele não existe mais",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está sendo usado na pasta  \"{dir}\". Por favor escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o arquivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o arquivo \"{file}\" pois ele já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\" pois ela já existe",
    "Could not fetch file details \"{file}\"" : "Não foi possível buscar os detalhes do arquivo \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Ocorreu um erro ao excluir o arquivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Sem resultados de pesquisa em outras pastas para {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Digite mais de dois caracteres para pesquisar em outras pastas",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
    "_%n file_::_%n files_" : ["%n arquivo","%n arquivos","%n arquivos"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n oculto","incluindo %n ocultos","incluindo %n ocultos"],
    "You do not have permission to upload or create files here" : "Você não tem permissão para upload ou criar arquivos aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n arquivo","Enviando %n arquivos","Enviando %n arquivos"],
    "New file/folder menu" : "Novo menu de arquivo/pasta",
    "Select file range" : "Selecionar o intervalo de arquivos",
    "{used} of {quota} used" : "{used} de {quota} usados",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido no nome do arquivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de arquivo permitido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "O armazenamento do {owner} está cheio, os arquivos não podem ser enviados ou sincronizados.",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "A pasta do grupo \"{mountPoint}\" está cheia, os arquivos não podem ser enviados ou sincronizados.",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "O armazenamento externo \"{mountPoint}\" está cheio, os arquivos não podem ser enviados ou sincronizados.",
    "Your storage is full, files cannot be updated or synced anymore!" : "Seu armazenamento está cheio, os arquivos não podem ser enviados ou sincronizados.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "O armazenamento do {owner} está quase cheio ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "A pasta de grupo \"{mountPoint}\" está quase cheia ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "O armazenamento externo \"{mountPoint}\" está quase cheio ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Seu armazenamento está quase cheio ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide \"{filter}\"","coincide \"{filter}\"","coincide \"{filter}\""],
    "View in folder" : "Exibir na pasta",
    "Copied!" : "Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar link direto (funciona apenas para usuários que tem acesso a este arquivo/pasta)",
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Favorited" : "Favoritado",
    "Favorite" : "Favorito",
    "You can only favorite a single file or folder at a time" : "Você só pode favoritar um único arquivo ou pasta de cada vez",
    "New folder" : "Nova pasta",
    "Upload file" : "Enviar arquivo",
    "Recent" : "Recentes",
    "Not favorited" : "Sem favoritos",
    "Remove from favorites" : "Excluir dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "An error occurred while trying to update the tags" : "Ocorreu um erro enquanto tentava atualizar as etiquetas",
    "Added to favorites" : "Adicionado aos favoritos",
    "Removed from favorites" : "Removido dos favoritos",
    "You added {file} to your favorites" : "Você adicionou {file} aos seus favoritos",
    "You removed {file} from your favorites" : "Você excluiu {file} dos seus favoritos",
    "File changes" : "Mudanças nos arquivos",
    "Created by {user}" : "Criado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Apagado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"usuário remoto\"",
    "You created {file}" : "Você criou {file}",
    "You created an encrypted file in {file}" : "Você criou um arquivo criptografado em {file}",
    "{user} created {file}" : "{user} criou {file}",
    "{user} created an encrypted file in {file}" : "{user} criou um arquivo criptografado em {file}",
    "{file} was created in a public folder" : "O arquivo {file} foi criado em uma pasta pública",
    "You changed {file}" : "Você modificou o arquivo {file}",
    "You changed an encrypted file in {file}" : "Você alterou um arquivo criptografado em {file}",
    "{user} changed {file}" : "{user} modificou {file}",
    "{user} changed an encrypted file in {file}" : "{user} alterou um arquivo criptografado em {file}",
    "You deleted {file}" : "Você excluiu {file}",
    "You deleted an encrypted file in {file}" : "Você excluiu um arquivo criptografado em {file}",
    "{user} deleted {file}" : "{user} excluiu o arquivo {file}",
    "{user} deleted an encrypted file in {file}" : "{user} excluiu um arquivo criptografado em {file}",
    "You restored {file}" : "Você restaurou o arquivo {file}",
    "{user} restored {file}" : "{user} restaurou {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Você renomeou {oldfile} (oculto) para {newfile} (oculto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Você renomeou {oldfile} (oculto) para {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Você renomeou {oldfile} para {newfile} (oculto)",
    "You renamed {oldfile} to {newfile}" : "Você renomeou o arquivo {oldfile} para {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renomeou {oldfile} (oculto) para {newfile} (oculto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renomeou {oldfile} (oculto) para {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renomeou {oldfile} para {newfile} (oculto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} para {newfile}",
    "You moved {oldfile} to {newfile}" : "Você moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Um arquivo foi adicionado ou removido de seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Um arquivo ou pasta foi <strong>modificado</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Um arquivo ou pasta favorita foi <strong>modificado</strong>",
    "All files" : "Todos os arquivos",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Envio (max. %s)",
    "Accept" : "Aceitar",
    "Reject" : "Rejeitar",
    "Incoming ownership transfer from {user}" : "Transferência de propriedade recebida de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Deseja aceitar {path}?\n\nObservação: O processo de transferência pode levar até 1 hora.",
    "Ownership transfer failed" : "Erro na transferência da propriedade",
    "Your ownership transfer of {path} to {user} failed." : "Erro na transferência da sua propriedade de {path} para {user}.",
    "The ownership transfer of {path} from {user} failed." : "Erro na transferência da propriedade de {path} de {user}.",
    "Ownership transfer done" : "A transferência da propriedade foi finalizada",
    "Your ownership transfer of {path} to {user} has completed." : "A transferência da sua propriedade de {path} para {user} foi concluída.",
    "The ownership transfer of {path} from {user} has completed." : "A transferência da propriedade de {path} de {user} foi concluída.",
    "in %s" : "em %s",
    "File Management" : "Gerenciamento de Arquivos",
    "Transfer ownership of a file or folder" : "Transferir a propriedade de um arquivo ou pasta",
    "Choose file or folder to transfer" : "Escolha o arquivo ou pasta a transferir",
    "Change" : "Mudar",
    "New owner" : "Novo proprietário",
    "Search users" : "Procurar usuários",
    "Choose a file or folder to transfer" : "Escolha o arquivo ou pasta a transferir",
    "Transfer" : "Transferir",
    "Transfer {path} to {userid}" : "Transferir {path} para {userid}",
    "Invalid path selected" : "Caminho inválido selecionado",
    "Ownership transfer request sent" : "Solicitação de transferência de propriedade enviada",
    "Cannot transfer ownership of a file or folder you do not own" : "Não é possível transferir a propriedade de um arquivo ou pasta que você não possui",
    "Tags" : "Etiquetas",
    "Unable to change the favourite state of the file" : "Não foi possível alterar o estado favorito do arquivo",
    "Error while loading the file data" : "Erro ao carregar os dados do arquivo",
    "Pick a template for {name}" : "Escolha um modelo para {name}",
    "Cancel" : "Cancelar",
    "Create" : "Criar ",
    "Create a new file with the selected template" : "Crie um novo arquivo com o modelo selecionado ",
    "Creating file" : "Criando arquivo ",
    "Blank" : "Em branco ",
    "Unable to create new file from template" : "Incapaz de criar novo arquivo a partir do modelo ",
    "Set up templates folder" : "Configurar pasta de modelos ",
    "Templates" : "Modelos ",
    "Unable to initialize the templates directory" : "Não foi possível inicializar o diretório de modelos ",
    "%s used" : "%s usado",
    "%1$s of %2$s used" : "%1$s usados de %2$s",
    "Files settings" : "Configurações de arquivos",
    "Show hidden files" : "Mostrar arquivos ocultos",
    "Crop image previews" : "Cortar visualizações de imagem",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Use este endereço para acessar seus Arquivos via WebDAV",
    "Toggle %1$s sublist" : "Alternar a sublista %1$s",
    "Toggle grid view" : "Alternar vista de grade",
    "No files in here" : "Nenhum arquivo aqui",
    "Upload some content or sync with your devices!" : "Envie um arquivo ou sincronize com seus dispositivos!",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Select all" : "Selecionar tudo",
    "Upload too large" : "Arquivo muito grande para envio",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os arquivos que você está tentando enviar excederam o tamanho máximo para arquivos no servidor.",
    "No favorites yet" : "Você não possui favoritos!",
    "Files and folders you mark as favorite will show up here" : "Suas pastas e arquivos favoritos serão exibidos aqui.",
    "Deleted files" : "Arquivos apagados",
    "Shares" : "Compartilhamentos",
    "Shared with others" : "Compartilhado com outros",
    "Shared with you" : "Compartilhado com você",
    "Shared by link" : "Compartilhado via link",
    "Deleted shares" : "Compartilhamentos apagados",
    "Pending shares" : "Compartilhamentos pendentes",
    "Text file" : "Arquivo texto",
    "New text file.txt" : "Novo arquivo.txt",
    "Select" : "Selecionar",
    "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar arquivos aqui",
    "New" : "Novo",
    "Cannot transfer ownership of a file or folder you don't own" : "Não é possível transferir a propriedade de um arquivo ou pasta que você não possui",
    "%s%% of %s used" : "%s%% usados de %s",
    "Settings" : "Configurações"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
